.. _api_datadict:

Data Dictionary Utilities (:mod:`pydicom.datadict`)
===================================================

.. currentmodule:: pydicom.datadict

Data dictionary functions

DICOM Data Dictionary
---------------------

.. autosummary::
   :toctree: generated/

   add_dict_entries
   add_dict_entry
   dictionary_description
   dictionary_has_tag
   dictionary_is_retired
   dictionary_keyword
   dictionary_VM
   dictionary_VR
   get_entry
   keyword_for_tag
   mask_match
   repeater_has_keyword
   repeater_has_tag
   tag_for_keyword

Private Data Dictionary
-----------------------

.. autosummary::
   :toctree: generated/

   add_private_dict_entries
   add_private_dict_entry
   get_private_entry
   private_dictionary_description
   private_dictionary_VM
   private_dictionary_VR
